/// <reference types="react" />
interface CodeTweenProps {
    /** A number between 0 and 1. */
    progress: number;
    /** The code to show when progress is 0. */
    prevCode: string;
    /** The code to show when progress is 1. */
    nextCode: string;
    /** The code to focus when progress is 0. */
    prevFocus: string | null;
    /** The code to focus when progress is 1. */
    nextFocus: string | null;
    /**
     * The language used to tokenize the code.
     * (you may need to import the language from prism)
     */
    language: string;
    /**
     * Ensure that we show at least `minColumns` of width
     * even when the largest line has less columns.
     */
    minColumns: number;
    /**
     * The available space for the code is memoized,
     * so, if `parentHeight` changes between renders
     * we recalculate the dimensions for the code.
     */
    parentHeight?: number;
}
export { CodeTween };
/**
 * Transitions between to pieces of code.
 * When `progress` is 0 it shows `prevCode`,
 * when `progress` is 1 it shows `nextCode`,
 * when `progress` is 0.5 its halfway between
 * `prevCode` and `nextCode`.
 */
declare function CodeTween({ prevCode, prevFocus, nextCode, nextFocus, progress, language, parentHeight, minColumns, }: CodeTweenProps): JSX.Element;
export declare function flatMap<T, U>(array: T[], callbackfn: (value: T, index: number, array: T[]) => U[]): U[];
